@@ -8,41 +8,20 @@ from plone.app.querystring.interfaces import IQuerystringRegistryReader
 from plone.batching import Batch
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.utils import getToolByName
-from zope.component import getMultiAdapter, getUtility, getUtilitiesFor
+from Products.CMFPlone.browser.search import munge_search_term
+from zope.component import getMultiAdapter
+from zope.component import getUtilitiesFor
+from zope.component import getUtility
 from zope.i18n import translate
 from zope.i18nmessageid import MessageFactory
 from zope.publisher.browser import BrowserView
 
 import json
 import logging
-import re
-
 
 logger = logging.getLogger("plone.app.querystring")
 _ = MessageFactory("plone")
 
-MULTISPACE = "\u3000"
-BAD_CHARS = ("?", "-", "+", "*", MULTISPACE)
-
-
-def quote_chars(s):
-    # We need to quote parentheses when searching text indices
-    if "(" in s:
-        s = s.replace("(", '"("')
-    if ")" in s:
-        s = s.replace(")", '")"')
-    if MULTISPACE in s:
-        s = s.replace(MULTISPACE, " ")
-    return s
-
-
-def quote(term):
-    # The terms and, or and not must be wrapped in quotes to avoid
-    # being parsed as logical query atoms.
-    if term.lower() in ("and", "or", "not"):
-        term = '"%s"' % term
-    return term
-
 
 class ContentListingView(BrowserView):
     """BrowserView for displaying query results"""
@@ -244,27 +223,8 @@ class QueryBuilder(BrowserView):
             query["SearchableText"] = self.munge_search_term(text)
         return query
 
-    def munge_search_term(self, query):
-        for char in BAD_CHARS:
-            query = query.replace(char, " ")
-
-        # extract quoted phrases first
-        quoted_phrases = re.findall(r'"([^"]*)"', query)
-        r = []
-        for qp in quoted_phrases:
-            # remove from original query
-            query = query.replace('"{qp}"'.format(qp=qp), "")
-            # replace with cleaned leading/trailing whitespaces
-            # and skip empty phrases
-            clean_qp = qp.strip()
-            if not clean_qp:
-                continue
-            r.append('"{clean_qp}"'.format(clean_qp=clean_qp))
-
-        r += map(quote, query.strip().split())
-        r = " AND ".join(r)
-        r = quote_chars(r) + ("*" if r and not r.endswith('"') else "")
-        return r
+    def munge_search_term(self, q):
+        return munge_search_term(q)
 
 
 class RegistryConfiguration(BrowserView):
